import { Component, Input, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';

interface Image {
  '@id': string;
  '@type': string;
  name: string;
  description: string;
  comments: string;
  uuid: string;
  id: number;
}

interface Partition {
  diskNumber: number;
  partitionNumber: number;
  associatedImageId?: string;
  associatedOgLive?: string;
}

@Component({
  selector: 'app-restore-image',
  templateUrl: './restore-image.component.html',
  styleUrls: ['./restore-image.component.css']
})
export class RestoreImageComponent implements OnInit {
  @Input() data: any;

  disks: { diskNumber: number; partitions: Partition[] }[] = [];
  availableImages: Image[] = [];
  availableOgLives: string[] = [];

  constructor(private http: HttpClient) {}

  ngOnInit(): void {
    this.initializeDisks();
    this.fetchAvailableImages();
    this.availableOgLives = ['LiveCD1', 'LiveCD2', 'LiveCD3'];
  }

  initializeDisks() {
    const partitionsFromData = this.data.partitions;
    const disksMap = new Map<number, Partition[]>();

    partitionsFromData.forEach((partition: any) => {
      if (!disksMap.has(partition.diskNumber)) {
        disksMap.set(partition.diskNumber, []);
      }

      disksMap.get(partition.diskNumber)!.push({
        diskNumber: partition.diskNumber,
        partitionNumber: partition.partitionNumber
      });
    });

    disksMap.forEach((partitions, diskNumber) => {
      this.disks.push({ diskNumber, partitions });
    });
  }

  fetchAvailableImages() {
    const url = 'http://127.0.0.1:8001/images?page=1&itemsPerPage=30';
    this.http.get(url).subscribe(
      (response: any) => {
        this.availableImages = response['hydra:member'];
      },
      (error) => {
        console.error('Error al obtener las imágenes:', error);
      }
    );
  }

  onImageSelected(partition: Partition, event: Event) {
    const selectElement = event.target as HTMLSelectElement;
    partition.associatedImageId = selectElement.value;
  }

  onOgLiveSelected(partition: Partition, event: Event) {
    const selectElement = event.target as HTMLSelectElement;
    partition.associatedOgLive = selectElement.value;
  }

  saveAssociations() {
    this.disks.forEach(disk => {
      disk.partitions.forEach(partition => {
        if (partition.associatedImageId || partition.associatedOgLive) {
          console.log(
            `Guardando para disco ${partition.diskNumber}, partición ${partition.partitionNumber}, ` +
            `Imagen ID: ${partition.associatedImageId}, OgLive: ${partition.associatedOgLive}`
          );
        }
      });
    });
  }
}
