import { HttpClient } from '@angular/common/http';
import {Component, Inject} from '@angular/core';
import {MAT_DIALOG_DATA} from "@angular/material/dialog";

@Component({
  selector: 'app-show-organizational-unit',
  templateUrl: './show-organizational-unit.component.html',
  styleUrl: './show-organizational-unit.component.css'
})
export class ShowOrganizationalUnitComponent {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  displayedColumns: string[] = ['property', 'value'];
  currentCalendar: any;
  generalData: any[] = [];
  networkData = [
  ];

  constructor(
    @Inject(MAT_DIALOG_DATA) public data: any,
    private http: HttpClient
  ) {
  }

  ngOnInit(): void {
    if (this.data.data.remoteCalendar) {
      this.loadCurrentCalendar(this.data.data.remoteCalendar.uuid);
    } else {
      this.initializeGeneralData(); 
    }
  }

  loadCurrentCalendar(uuid: string): void {
    const apiUrl = `${this.baseUrl}/remote-calendars/${uuid}`;
    this.http.get<any>(apiUrl).subscribe(
      response => {
        this.currentCalendar = response.name;
        this.initializeGeneralData();  
      },
      error => {
        console.error('Error loading current calendar', error);
        this.initializeGeneralData();  
      }
    );
  }

  initializeGeneralData(): void {
    this.generalData = [
      { property: 'Nombre', value: this.data.data.name },
      { property: 'Uuid', value: this.data.data.uuid },
      { property: 'Descripción', value: this.data.data.description },
      { property: 'Comentarios', value: this.data.data.comments },
      { property: 'Tipo', value: this.data.data.type },
      { property: 'Unidad organizativa superior', value: this.data.data.parent ? this.data.data.parent.name : '-' },
      { property: 'Creado por', value: this.data.data.createdBy },
      { property: 'Creado el', value: this.data.data.createdAt },
      { property: 'Calendario asociado', value: this.data.data.remoteCalendar ? this.currentCalendar : '-' }
    ];
  }
}
