import { Component, OnInit } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { HttpClient } from '@angular/common/http';
import { MatTableDataSource } from '@angular/material/table';
import { ToastrService } from 'ngx-toastr';
import { DatePipe } from '@angular/common';
import { CreateImageComponent } from './create-image/create-image.component';
import {CreateCommandComponent} from "../commands/main-commands/create-command/create-command.component";
import {DeleteModalComponent} from "../../shared/delete_modal/delete-modal/delete-modal.component";

@Component({
  selector: 'app-images',
  templateUrl: './images.component.html',
  styleUrls: ['./images.component.css']
})
export class ImagesComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  dataSource = new MatTableDataSource<any>();
  length: number = 0;
  itemsPerPage: number = 10;
  page: number = 0;
  loading: boolean = false;
  filters: { [key: string]: string } = {};
  datePipe: DatePipe = new DatePipe('es-ES');
  columns = [
    {
      columnDef: 'id',
      header: 'Id',
      cell: (image: any) => `${image.id}`
    },
    {
      columnDef: 'name',
      header: 'Nombre de imagen',
      cell: (image: any) => `${image.name}`
    },
    {
      columnDef: 'softwareProfile',
      header: 'Perfil de software',
      cell: (image: any) => `${image.softwareProfile?.description}`
    },
    {
      columnDef: 'imageRepository',
      header: 'Repositorio',
      cell: (image: any) => `${image.imageRepository?.name}`
    },
    {
      columnDef: 'remotePc',
      header: 'Remote Pc',
      cell: (image: any) => `${image.remotePc}`
    },
    {
      columnDef: 'createdAt',
      header: 'Fecha de creación',
      cell: (image: any) => `${this.datePipe.transform(image.createdAt, 'dd/MM/yyyy hh:mm:ss')}`
    }
  ];
  displayedColumns = [...this.columns.map(column => column.columnDef), 'actions'];

  private apiUrl = `${this.baseUrl}/images`;

  constructor(
    public dialog: MatDialog,
    private http: HttpClient,
    private toastService: ToastrService
  ) {}

  ngOnInit(): void {
    this.search();
  }

  addImage(): void {
    const dialogRef = this.dialog.open(CreateImageComponent, {
      width: '600px'
    });

    dialogRef.afterClosed().subscribe(() => {
      this.search();
    });
  }

  search(): void {
    this.loading = true;
    this.http.get<any>(`${this.apiUrl}?page=${this.page +1 }&itemsPerPage=${this.itemsPerPage}`, { params: this.filters }).subscribe(
      data => {
        this.dataSource.data = data['hydra:member'];
        this.length = data['hydra:totalItems'];
        this.loading = false;
      },
      error => {
        console.error('Error fetching images', error);
        this.loading = false;
      }
    );
  }

  editImage(event: MouseEvent, image: any): void {
    event.stopPropagation();
    this.dialog.open(CreateImageComponent, {
      width: '600px',
      data: image['@id']
    }).afterClosed().subscribe(() => this.search());
  }

  deleteImage(event: MouseEvent,command: any): void {
    event.stopPropagation();
    this.dialog.open(DeleteModalComponent, {
      width: '300px',
      data: { name: command.name },
    }).afterClosed().subscribe((result) => {
      if (result) {
        this.http.delete(`${this.apiUrl}/${command.uuid}`).subscribe({
          next: () => {
            this.toastService.success('Imagen eliminada con éxito');
            this.search();
          },
          error: (error) => {
            console.error('Error al eliminar la imagen:', error);
          }
        });
      }
    });
  }

  onPageChange(event: any): void {
    this.page = event.pageIndex;
    this.itemsPerPage = event.pageSize;
    this.length = event.length;
    this.search();
  }
}
