import { HttpClient } from '@angular/common/http';
import { Component, Inject, OnInit } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';

@Component({
  selector: 'app-create-pxe-boot-file',
  templateUrl: './create-pxe-boot-file.component.html',
  styleUrls: ['./create-pxe-boot-file.component.css']
})
export class CreatePxeBootFileComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  pxeTemplates: any[] = [];
  selectedPxeTemplate: string | undefined;
  selectedElements: any;
  isEditMode: boolean = false;

  constructor(
    private toastService: ToastrService,
    private http: HttpClient,
    private dialogRef: MatDialogRef<CreatePxeBootFileComponent>,
    @Inject(MAT_DIALOG_DATA) public data: { clients: any[], bootFile?: any }
  ) {}

  ngOnInit(): void {
    this.selectedElements = this.data
    this.loadPxeTemplates();
    if (this.data.bootFile) {
      this.isEditMode = true;
      this.selectedPxeTemplate = this.data.bootFile.template.uuid;
    }
  }

  loadPxeTemplates(): void {
    this.http.get(`${this.baseUrl}/pxe-templates?page=1&itemsPerPage=30`)
      .subscribe((response: any) => {
        this.pxeTemplates = response['hydra:member'];
      }, error => {
        console.error('Error fetching PXE templates:', error);
      });
  }

  onCancel(): void {
    this.dialogRef.close();
  }

  onSave(): void {
    if (this.selectedPxeTemplate) {
      const payload = {
        template: `/pxe-templates/${this.selectedPxeTemplate}`,
        clients: this.selectedElements
      };

      if (this.isEditMode && this.data.bootFile) {
        this.http.put(`${this.baseUrl}/pxe-boot-files/${this.data.bootFile.uuid}`, payload)
          .subscribe({
            next: response => {
              this.toastService.success('PXE actualizado con éxito');
              this.dialogRef.close(true);
            },
            error: error => {
              this.toastService.error('Error al actualizar el PXE', error);
            }
          });
      } else {
        this.http.post(`${this.baseUrl}/pxe-boot-files`, payload)
          .subscribe({
            next: response => {
              this.toastService.success('PXE asignado con éxito');
              this.dialogRef.close(true);
            },
            error: error => {
              this.toastService.error('Error enviando el payload', error);
            }
          });
      }
    } else {
      this.toastService.error('No se ha seleccionado ninguna plantilla PXE');
    }
  }
}
