import {Component, Inject} from '@angular/core';
import {FormBuilder, FormGroup, Validators} from "@angular/forms";
import {MAT_DIALOG_DATA, MatDialog, MatDialogRef} from "@angular/material/dialog";
import {HttpClient} from "@angular/common/http";
import {ToastrService} from "ngx-toastr";
import {DeleteModalComponent} from "../../../../shared/delete_modal/delete-modal/delete-modal.component";
import {Observable} from "rxjs";
import {
  ServerInfoDialogComponent
} from "../../../ogdhcp/og-dhcp-subnets/server-info-dialog/server-info-dialog.component";

@Component({
  selector: 'app-clients',
  templateUrl: './clients.component.html',
  styleUrl: './clients.component.css'
})
export class ClientsComponent {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  templateForm!: FormGroup;
  clients: any[] = [];
  alertMessage: string | null = null;

  constructor(
    public dialogRef: MatDialogRef<ClientsComponent>,
    public dialog: MatDialog,
    private http: HttpClient,
    private toastService: ToastrService,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {}

  ngOnInit() {
    this.getPxeClients()
  }

  getPxeClients(): void {
    this.http.get<any>(`${this.baseUrl}/clients?template.id=${this.data.data.id}`).subscribe({
      next: data => {
        this.clients = data['hydra:member']
      },
      error: error => {
        console.error('Error al obtener los clientes PXE:', error);
      }
    });
  }

  addClientToTemplate(client: any): void {
    const postData = {
      client: client['@id']
    };

    this.http.post(`${this.baseUrl}/pxe-templates/${this.data.data.uuid}/sync-client`, postData).subscribe(
      response => {
        this.toastService.success('Clientes asignados correctamente');
        this.getPxeClients()
      },
      error => {
        this.toastService.error(error.error['hydra:description']);
      }
    );
  }

  loadAlert(client: any): Observable<any> {
    return this.http.post<any>(`${this.baseUrl}/clients/server/${client.uuid}/get-pxe`, {});
  }

  showInfo(client:any) {
    this.loadAlert(client).subscribe(
      response => {
        this.alertMessage = response.message;

        this.dialog.open(ServerInfoDialogComponent, {
          width: '600px',
          data: {
            message: this.alertMessage
          }
        });
      },
      error => {
        console.error('Error al cargar la información del alert', error);
      }
    );
  }

  deleteClient(client: any): void {
    const dialogRef = this.dialog.open(DeleteModalComponent, {
      width: '300px',
      data: { name: client.name }
    });

    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        this.http.post(`${this.baseUrl}/pxe-templates/${this.data.data.uuid}/delete-client`, { client: client['@id'] }).subscribe({
          next: () => {
            this.toastService.success('Cliente eliminado exitosamente');
            this.dialogRef.close();
          },
          error: (error) => {
            this.toastService.error(error.error['hydra:description']);
          }
        });
      }})
  }

  onCancel(): void {
    this.dialogRef.close(false);
  }
}
