import { HttpClient } from '@angular/common/http';
import { Component } from '@angular/core';
import { CreatePxeTemplateComponent } from './create-pxeTemplate/create-pxe-template.component'; // Asegúrate de que el path sea correcto
import { MatDialog } from '@angular/material/dialog';
import { MatTableDataSource } from '@angular/material/table';
import { PageEvent } from '@angular/material/paginator';
import { ToastrService } from 'ngx-toastr';
import { DatePipe } from '@angular/common';
import { DeleteModalComponent } from '../../../shared/delete_modal/delete-modal/delete-modal.component';
import { DataService } from './data.service';
import {
  ShowOrganizationalUnitComponent
} from "../../groups/shared/organizational-units/show-organizational-unit/show-organizational-unit.component";
import {ShowTemplateContentComponent} from "./show-template-content/show-template-content.component";
import {ServerInfoDialogComponent} from "../../ogdhcp/og-dhcp-subnets/server-info-dialog/server-info-dialog.component";
import {
  AddClientsToSubnetComponent
} from "../../ogdhcp/og-dhcp-subnets/add-clients-to-subnet/add-clients-to-subnet.component";
import {Subnet} from "../../ogdhcp/og-dhcp-subnets/og-dhcp-subnets.component";
import {AddClientsToPxeComponent} from "./add-clients-to-pxe/add-clients-to-pxe.component";
import {Observable} from "rxjs";
import {ClientsComponent} from "./clients/clients.component";

@Component({
  selector: 'app-pxe',
  templateUrl: './pxe.component.html',
  styleUrls: ['./pxe.component.css']
})
export class PxeComponent {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  pxeTemplates: any[] = [];
  currentPage: number = 1;
  dataSource = new MatTableDataSource<any>();
  length: number = 0;
  itemsPerPage: number = 10;
  page: number = 1;
  pageSizeOptions: number[] = [5, 10, 20, 40, 100];
  selectedElements: string[] = [];
  loading:boolean = false;
  filters: { [key: string]: string } = {};
  alertMessage: string | null = null;
  datePipe: DatePipe = new DatePipe('es-ES');
  selectedItem: any = null;
  previewContent: any | null = null;
  columns = [
    {
      columnDef: 'id',
      header: 'ID',
      cell: (user: any) => `${user.id}`
    },
    {
      columnDef: 'name',
      header: 'Nombre de la plantilla',
      cell: (user: any) => `${user.name}`
    },
    {
      columnDef: 'synchronized',
      header: 'Sincronizado',
      cell: (user: any) => `${user.synchronized}`
    },
    {
      columnDef: 'createdAt',
      header: 'Fecha de creación',
      cell: (user: any) => `${this.datePipe.transform(user.createdAt, 'dd/MM/yyyy hh:mm:ss')}`
    }
  ];
  displayedColumns = [...this.columns.map(column => column.columnDef), 'actions'];

  private apiUrl = `${this.baseUrl}/pxe-templates`;

  constructor(
    public dialog: MatDialog,
    private http: HttpClient,
    private toastService: ToastrService,
    private dataService: DataService
  ) { }

  ngOnInit(): void {
    this.search();
  }

  search(): void {
    this.loading = true;
    this.dataService.getPxeTemplates(this.filters).subscribe(
      data => {
        this.dataSource.data = data;
        this.loading = false;
      },
      error => {
        console.error('Error fetching pxe templates', error);
        this.loading = false;
      }
    );
  }

  addPxeTemplate() {
    const dialogRef = this.dialog.open(CreatePxeTemplateComponent, {
      width: '800px'
    });

    dialogRef.afterClosed().subscribe(() => {
      this.search();
    });
  }

  editPxeTemplate(template: any) {
    const dialogRef = this.dialog.open(CreatePxeTemplateComponent, {
      data: template, // Pasa los datos del template para edición
      width: '800px'
    });

    dialogRef.afterClosed().subscribe(() => {
      this.search();
    });
  }

  toggleAction(image: any, action: string): void {
    switch (action) {
      case 'create':
        this.http.post(`${this.apiUrl}/server/${image.uuid}/post`, {}).subscribe({
          next: (response) => {
            this.search();
            // @ts-ignore
            this.toastService.success(response.success);
          },
          error: (error) => {
            this.toastService.error(error.error.error);
          }
        });
        break;
      case 'sync':
        this.http.get(`${this.apiUrl}/server/${image.uuid}/get`, {}).subscribe({
          next: (response) => {
            this.search();
            // @ts-ignore
            this.toastService.success(response.success);
          },
          error: (error) => {
            this.toastService.error(error.error.error);
          }
        });
        break;
      case 'delete':
        this.http.post(`${this.apiUrl}/server/${image.uuid}/delete`, {}).subscribe({
          next: () => {
            this.toastService.success('Plantilla eliminada correctamente');
            this.search();
          },
          error: (error) => {
            this.toastService.error(error.error.error);
          }
        });
        break;
      default:
        console.error('Acción no soportada:', action);
        break;
    }
  }

  showTemplate(event: MouseEvent, data: any): void {
    event.stopPropagation();
    const dialogRef = this.dialog.open(ShowTemplateContentComponent, { data: { data }, width: '700px'});
  }

  editClients(event: MouseEvent, data: any): void {
    event.stopPropagation();
    const dialogRef = this.dialog.open(ClientsComponent, { data: { data }, width: '700px'});
  }

  syncTemplates() {
    this.http.post(`${this.apiUrl}/sync`, {})
      .subscribe(response => {
        this.toastService.success('Sincronización completada');
        this.search()
      }, error => {
        console.error('Error al sincronizar', error);
        this.toastService.error('Error al sincronizar');
      });
  }

  addClientsToPxe(template: Subnet) {
    const dialogRef = this.dialog.open(AddClientsToPxeComponent, {
      width: '600px',
      data: { subnetUuid: template.uuid, subnetName: template.name }
    });

    dialogRef.afterClosed().subscribe(result => {
      this.search();
    });
  }

  applyFilter() {
    this.http.get<any>(`${this.apiUrl}?page=${this.page}&itemsPerPage=${this.itemsPerPage}`).subscribe({
      next: (response) => {
        this.dataSource.data = response['hydra:member'];
        this.length = response['hydra:totalItems'];
      },
      error: (error) => {
        console.error('Error al cargar las imágenes:', error);
      }
    });
  }

  loadAlert(): Observable<any> {
    return this.http.get<any>(`${this.apiUrl}/server/get-collection`);
  }

  openSubnetInfoDialog() {
    this.loadAlert().subscribe(
      response => {
        this.alertMessage = response.message;

        this.dialog.open(ServerInfoDialogComponent, {
          width: '600px',
          data: {
            message: this.alertMessage
          }
        });
      },
      error => {
        console.error('Error al cargar la información del alert', error);
      }
    );
  }

  onPageChange(event: PageEvent) {
    this.page = event.pageIndex;
    this.itemsPerPage = event.pageSize;
    this.applyFilter();
  }
}
