import { Component, OnInit, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import {Observable, startWith} from "rxjs";
import {map} from "rxjs/operators";
import {FormControl} from "@angular/forms";
import {ToastrService} from "ngx-toastr";

@Component({
  selector: 'app-add-clients-to-subnet',
  templateUrl: './add-clients-to-subnet.component.html',
  styleUrls: ['./add-clients-to-subnet.component.css']
})
export class AddClientsToSubnetComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  clients: any[] = [];
  selectedClients: any[] = [];
  loading: boolean = true;
  filters: { [key: string]: string } = {};
  filteredClients!: Observable<any[]>;
  clientControl = new FormControl();

  constructor(
    private http: HttpClient,
    public dialogRef: MatDialogRef<AddClientsToSubnetComponent>,
    private toastService: ToastrService,
    @Inject(MAT_DIALOG_DATA) public data: { subnetUuid: string, subnetName: string }
     ) {}

  ngOnInit(): void {
    console.log('Selected subnet UUID:', this.data);
    this.loading = true;

    this.loadClients();

    this.filteredClients = this.clientControl.valueChanges.pipe(
      startWith(''),
      map(value => (typeof value === 'string' ? value : value?.name)),
      map(name => (name ? this._filterClients(name) : this.clients.slice()))
    );
  }

  loadClients() {
    this.http.get<any>( `${this.baseUrl}/clients?&page=1&itemsPerPage=10000&exists[subnet]=false`).subscribe(
      response => {
        this.clients = response['hydra:member'];
        this.loading = false;
      },
      error => {
        console.error('Error fetching parent units:', error);
        this.loading = false;
      }
    );
  }

  save() {
    this.selectedClients.forEach(client => {
      const postData = {
        client: client['@id']
      };

      this.http.post(`${this.baseUrl}/og-dhcp/server/${this.data.subnetUuid}/post-host`, postData).subscribe(
        response => {
          this.toastService.success(`Cliente ${client.name} asignado correctamente`);
        },
        error => {
          console.error(`Error al asignar el cliente ${client.name}:`, error);
          this.toastService.error(`Error al asignar el cliente ${client.name}: ${error.error['hydra:description']}`);
        }
      );
    });

    this.dialogRef.close(this.selectedClients);
  }

  close() {
    this.dialogRef.close();
  }

  removeClient(client: any) {
    const index = this.selectedClients.indexOf(client);
    if (index >= 0) {
      this.selectedClients.splice(index, 1);
    }
  }

  private _filterClients(name: string): any[] {
    const filterValue = name.toLowerCase();
    return this.clients.filter(client => client.name.toLowerCase().includes(filterValue));
  }

  displayFnClient(client: any): string {
    return client && client.name ? client.name : '';
  }

  onOptionClientSelected(client: any) {
    if (!this.selectedClients.includes(client)) {
      this.selectedClients.push(client);
    }
    this.clientControl.setValue('');
  }
}
