import { HttpClient } from '@angular/common/http';
import { Component, Inject, OnInit } from '@angular/core';
import {MAT_DIALOG_DATA, MatDialog, MatDialogRef} from '@angular/material/dialog';
import { ToastrService } from 'ngx-toastr';
import {DeleteModalComponent} from "../../../../shared/delete_modal/delete-modal/delete-modal.component";

@Component({
  selector: 'app-create-subnet',
  templateUrl: './create-subnet.component.html',
  styleUrls: ['./create-subnet.component.css']
})
export class CreateSubnetComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  subnetId: string | null = null;
  name: string = '';
  netmask: string = '';
  ipAddress: string = '';
  nextServer: string = '';
  bootFileName: string = '';
  syncronized: boolean = false;
  serverId: number = 0;
  clients: any[] = [];
  isEditMode: boolean = false;

  constructor(
    private toastService: ToastrService,
    private http: HttpClient,
    public dialogRef: MatDialogRef<CreateSubnetComponent>,
    public dialog: MatDialog,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) { }

  ngOnInit(): void {
    if (this.data) {
      this.loadData();
      this.isEditMode = true;
    }
  }

  loadData() {
    this.subnetId = this.data.uuid;
    this.name = this.data.name;
    this.netmask = this.data.netmask;
    this.ipAddress = this.data.ipAddress;
    this.nextServer = this.data.nextServer;
    this.bootFileName = this.data.bootFileName;
    this.syncronized = this.data.syncronized;
    this.serverId = this.data.serverId;
    this.clients = this.data.clients
  }

  onNoClick(): void {
    this.dialogRef.close();
  }

  addNetworkConfig(): void {
    const payload = {
      name: this.name,
      netmask: this.netmask,
      ipAddress: this.ipAddress,
      nextServer: this.nextServer,
      bootFileName: this.bootFileName
    };

    if (!this.data){
      this.http.post(`${this.baseUrl}/subnets`, payload)
        .subscribe({
          next: (response) => {
            console.log('Success:', response);
            this.toastService.success('Configuración de red añadida exitosamente');
            this.dialogRef.close();
          },
          error: (error) => {
            console.error('Error:', error);
            this.toastService.error(error.error['hydra:description']);
          }
        });
    } else {
      this.http.patch(`${this.baseUrl}/subnets/${this.subnetId}`, payload)
        .subscribe({
          next: (response) => {
            console.log('Success:', response);
            this.toastService.success('Configuración de red actualizada exitosamente');
            this.dialogRef.close();
          },
          error: (error) => {
            console.error('Error:', error);
            this.toastService.error(error.error['hydra:description']);
          }
        });
    }
  }

  deleteClient(client: any): void {
    const dialogRef = this.dialog.open(DeleteModalComponent, {
      width: '300px',
      data: { name: client.name }
    });

    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        this.http.delete(`${this.baseUrl}/og-dhcp/server/${this.subnetId}/delete-host/${client.uuid}`, {}).subscribe({
          next: () => {
            this.toastService.success('Cliente eliminado exitosamente');
            this.dialogRef.close();
          },
          error: (error) => {
            this.toastService.error(error.error['hydra:description']);
          }
        });
      }})
  }
}
