import { Component } from '@angular/core';
import {HttpClient} from "@angular/common/http";

@Component({
  selector: 'app-status',
  templateUrl: './status.component.html',
  styleUrl: './status.component.css'
})
export class StatusComponent {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  diskUsage: any = {};
  servicesStatus: any = {};
  subnets: any[] = [];
  diskUsageChartData: any[] = [];

  view: [number, number] = [1100, 500];

  gradient: boolean = true;
  showLegend: boolean = true;
  showLabels: boolean = true;
  isDoughnut: boolean = true;
  colorScheme: any = {
    domain: ['#FF6384', '#3f51b5']
  };

  constructor(private http: HttpClient) {}

  ngOnInit(): void {
    this.loadStatus();
  }
  loadStatus(): void {
    this.http.get<any>(`${this.baseUrl}/og-dhcp/status`).subscribe(data => {
      this.diskUsage = data.message.disk_usage;
      this.servicesStatus = data.message.services_status;
      this.subnets = data.message.subnets;

      this.diskUsageChartData = [
        {
          name: 'Usado',
          value: parseFloat(this.diskUsage.used)
        },
        {
          name: 'Disponible',
          value: parseFloat(this.diskUsage.available)
        }
      ];
    }, error => {
      console.error('Error fetching status', error);
    });
  }

  getServices(): { name: string, status: string }[] {
    return Object.keys(this.servicesStatus).map(key => ({
      name: key,
      status: this.servicesStatus[key]
    }));
  }
}
