import {Component, Inject} from '@angular/core';
import {FormBuilder, FormGroup, Validators} from "@angular/forms";
import {HttpClient} from "@angular/common/http";
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material/dialog";
import {ToastrService} from "ngx-toastr";
import {DataService} from "../../images/data.service";

@Component({
  selector: 'app-create-repository',
  templateUrl: './create-repository.component.html',
  styleUrl: './create-repository.component.css'
})
export class CreateRepositoryComponent {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  imageForm: FormGroup<any>;
  repositoryId: string | null = null;
  softwareProfiles: any[] = [];

  constructor(
    private fb: FormBuilder,
    private http: HttpClient,
    public dialogRef: MatDialogRef<CreateRepositoryComponent>,
    private toastService: ToastrService,
    private dataService: DataService,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {
    this.imageForm = this.fb.group({
      name: ['', Validators.required],
      ip: [''],
      comments: [''],
    });
  }

  ngOnInit() {
    if (this.data) {
      this.load()
    }
  }

  load(): void {
    this.dataService.getImage(this.data).subscribe({
      next: (response) => {
        this.imageForm = this.fb.group({
          name: [response.name, Validators.required],
          ip: [response.ip],
          comments: [response.comments],
        });
        this.repositoryId = response['@id'];
      },
      error: (err) => {
        console.error('Error fetching remote calendar:', err);
      }
    });
  }

  save(): void {
    const payload = {
      name: this.imageForm.value.name,
      ip: this.imageForm.value.ip,
      comments: this.imageForm.value.comments,
    };

    if (this.repositoryId) {
      this.http.put(`${this.baseUrl}${this.repositoryId}`, payload).subscribe(
        (response) => {
          this.toastService.success('Imagen editada correctamente');
          this.dialogRef.close();
        },
        (error) => {
          this.toastService.error(error['error']['hydra:description']);
          console.error('Error al editar la imagen', error);
        }
      );
    } else {
      this.http.post(`${this.baseUrl}/image-repositories`, payload).subscribe(
        (response) => {
          this.toastService.success('Imagen añadida correctamente');
          this.dialogRef.close();
        },
        (error) => {
          this.toastService.error(error['error']['hydra:description']);
          console.error('Error al añadir la imagen', error);
        }
      );
    }
  }

  close(): void {
    this.dialogRef.close();
  }
}
