import { Injectable } from '@angular/core';
import {HttpClient, HttpParams} from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { catchError, map } from 'rxjs/operators';

@Injectable({
  providedIn: 'root'
})
export class DataService {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  private apiUrl = `${this.baseUrl}/software`;

  constructor(private http: HttpClient) {}

  getSoftwareCollection(filters: { [key: string]: string }): Observable<any[]> {
    const params = new HttpParams({ fromObject: filters });

    return this.http.get<any>(this.apiUrl, { params }).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member'];
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching remote calendars', error);
        return throwError(error);
      })
    );
  }

  getSoftware(id: string): Observable<any> {
    return this.http.get<any>(`${this.baseUrl}${id}`).pipe(
      map(response => {
        if (response.name) {
          return response;
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching calendar', error);
        return throwError(error);
      })
    );
  }
}
